@@ -230,11 +230,3 @@ fix_value_labels <- function(data, setup, value_label_fix) {
   return(data)
 }
 
-
-.onAttach <- function(libname, pkgname) {
-  package_citation <- "Kaplan, J (2023). asciiSetupReader: PReads Fixed-Width ASCII Data Files (.txt or .dat) that
-    Have Accompanying Setup Files (.sps or .sas). Version 2.5.1. URL: https://github.com/jacobkap/asciiSetupReader, https://jacobkap.github.io/asciiSetupReader/."
-  packageStartupMessage("Thank you for using asciiSetupReader!")
-  packageStartupMessage("To acknowledge our work, please cite the package:")
-  packageStartupMessage(package_citation)
-}
